# BATS.py
Python bindings for the [BATS library](https://github.com/CompTop/BATS).

Note that the C++ repository is the main library, and contains more features.  This repository provides bindings for a subset of the functionality of BATS, and is under active development.

Documentation, examples, and tutorials can be found at [comptop.github.io/BATS.py](https://comptop.github.io/BATS.py/#/)
